==> zither-1.1.15.tar.gz: zither_prj/apollon/monitor_comp2.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";


$view_mode = enco($_GET["VIEW_MODE"]);
$view_name = enco($_GET["VIEW_NAME"]);

$cname = enco($_GET["CNAME"]);
$free4 = enco($_GET["FREE4"]);
$ye = enco($_GET["YE"]);
$mo = enco($_GET["MO"]);
$da = enco($_GET["DA"]);
$monitor = enco($_GET["MONITOR"]);
$proto = enco($_GET["PROTO"]);
$prino = enco($_GET["PRINO"]);
$port = enco($_GET["PORT"]);
$by = enco($_GET["BY"]);

$ye_ch = enco($_GET["YE_CH"]);
$mo_ch = enco($_GET["MO_CH"]);
$da_ch = enco($_GET["DA_CH"]);
$monitor_ch = enco($_GET["MONITOR_CH"]);
$proto_ch = enco($_GET["PROTO_CH"]);
$prino_ch = enco($_GET["PRINO_CH"]);
$port_ch = enco($_GET["PORT_CH"]);

$ncol1 = "bgcolor=#f0f0d2";
$ncol2 = "bgcolor=#d2f0f0";
$acol1 = "bgcolor=#e0e0a0";
$acol2 = "bgcolor=#a0e0e0";
$bcol1 = "bgcolor=#f0c0c0";
$bcol2 = "bgcolor=#c0c0f0";


if(0 != strlen($cname)){
   $select_data = "select * from errlog where " . "cname = '$cname'";
   }
else{
   $select_data = "select * from errlog where " . "cname LIKE '%'";
   }

if(0 != strlen($free4)){
   $select_data = $select_data . " and free4 = '$free4'";
   }
if(0 != strlen($monitor)){
   if(0 == strcmp("on", $monitor_ch)){
      $select_data = $select_data . " and monitor != '$monitor'";
      }
   else{
      $select_data = $select_data . " and monitor='$monitor'";
      }
   }
if(0 != strlen($ye)){
   if(0 == strcmp("on", $ye_ch)){
      $select_data = $select_data . " and ye != '$ye'";
      }
   else{
      $select_data = $select_data . " and ye='$ye'";
      }
   }
if(0 != strlen($mo)){
   if(0 == strcmp("on", $mo_ch)){
      $select_data = $select_data . " and mo != '$mo'";
      }
   else{
      $select_data = $select_data . " and mo='$mo'";
      }
   }
if(0 != strlen($da)){
   if(0 == strcmp("on", $da_ch)){
      $select_data = $select_data . " and da != '$da'";
      }
   else{
      $select_data = $select_data . " and da='$da'";
      }
   }
if(0 != strlen($proto)){
   if(0 == strcmp("on", $proto_ch)){
      $select_data = $select_data . " and proto != '$proto'";
      }
   else{
      $select_data = $select_data . " and proto = '$proto'";
      }
   }
if(0 != strlen($port)){
   if(0 == strcmp("on", $port_ch)){
      $select_data = $select_data . " and port != '$port'";
      }
   else{
      $select_data = $select_data . " and port = '$port'";
      }
   }
if(0 != strlen($prino)){
   if(0 == strcmp("on", $prino_ch)){
      $select_data = $select_data . " and prino != '$prino'";
      }
   else{
      $select_data = $select_data . " and prino = '$prino'";
      }
   }


echo "<title>zither monitorring save info</title>";
echo "</head>";
echo "<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

echo "<TABLE border=0 bgcolor=FFA500 cellspacing=3 cellpadding=0 width=100%>";
echo "<tr><td align=left><font color=ffffff><b> -> ̥顼</b></font></td></tr>";
echo "</table><br><br>";

print("<font size=1>");
print($version_name);
print("\n");
print(date("Y m d g i s A"));
print("\n");
print($select_data);


$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

echo "<TABLE border=0  WIDTH=50% height=10% BGCOLOR=$my_bocolor>";

echo "<tr bgcolor='#D9DBED'>";
echo "<td>";
print("ȯ(24H)");
echo "</td>";
echo "<td>";
print("");
echo "</td>";
echo "<td>";

echo "</td>";
echo "</tr>";


// ǡ
for($count=0; $count < 24; $count++){

   $select_data_2 = " and ha='$count'";

   $result = pg_query($conn, "$select_data$select_data_2");
   if(!$result){
      print("bud query\n");
      exit;
      }
   $num = pg_num_rows($result);

   if($maxlen < $num){
      $maxlen = $num;
      }
   $ardata[$count] = $num;

   pg_free_result($result);
   $num = 0;
   }


// ǡɽ
for($count=0; $count < 24; $count++){
   echo "<tr bgcolor='#D9DBED'>";

   echo "<td>";
   print($count);
   echo "</td>";

   echo "<td>";
   print($ardata[$count]);
   echo "</td>";

   echo "<td>";

   $width_size = $ardata[$count] / ($maxlen / $by);
   echo "<img src='../img/blue.png' height=10 width=$width_size alt='apoimg'>";
   $width_size = 0;

   echo "</td>";
   echo "</tr>";

   }


echo "</table>";
echo "</font>";

pg_Close($conn);

?>
</pre>
<br>
<br>
</body>
</html>

==> zither-1.1.16.tar.gz: zither_prj/apollon/monitor_comp2.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";


$view_mode = enco($_GET["VIEW_MODE"]);
$view_name = enco($_GET["VIEW_NAME"]);

$cname = enco($_GET["CNAME"]);
$free4 = enco($_GET["FREE4"]);
$ye = enco($_GET["YE"]);
$mo = enco($_GET["MO"]);
$da = enco($_GET["DA"]);
$monitor = enco($_GET["MONITOR"]);
$proto = enco($_GET["PROTO"]);
$prino = enco($_GET["PRINO"]);
$port = enco($_GET["PORT"]);
$by = enco($_GET["BY"]);

$ye_ch = enco($_GET["YE_CH"]);
$mo_ch = enco($_GET["MO_CH"]);
$da_ch = enco($_GET["DA_CH"]);
$monitor_ch = enco($_GET["MONITOR_CH"]);
$proto_ch = enco($_GET["PROTO_CH"]);
$prino_ch = enco($_GET["PRINO_CH"]);
$port_ch = enco($_GET["PORT_CH"]);

$ncol1 = "bgcolor=#f0f0d2";
$ncol2 = "bgcolor=#d2f0f0";
$acol1 = "bgcolor=#e0e0a0";
$acol2 = "bgcolor=#a0e0e0";
$bcol1 = "bgcolor=#f0c0c0";
$bcol2 = "bgcolor=#c0c0f0";


if(0 != strlen($cname)){
   $select_data = "select * from errlog where " . "cname = '$cname'";
   }
else{
   $select_data = "select * from errlog where " . "cname LIKE '%'";
   }

if(0 != strlen($free4)){
   $select_data = $select_data . " and free4 = '$free4'";
   }
if(0 != strlen($monitor)){
   if(0 == strcmp("on", $monitor_ch)){
      $select_data = $select_data . " and monitor != '$monitor'";
      }
   else{
      $select_data = $select_data . " and monitor='$monitor'";
      }
   }
if(0 != strlen($ye)){
   if(0 == strcmp("on", $ye_ch)){
      $select_data = $select_data . " and ye != '$ye'";
      }
   else{
      $select_data = $select_data . " and ye='$ye'";
      }
   }
if(0 != strlen($mo)){
   if(0 == strcmp("on", $mo_ch)){
      $select_data = $select_data . " and mo != '$mo'";
      }
   else{
      $select_data = $select_data . " and mo='$mo'";
      }
   }
if(0 != strlen($da)){
   if(0 == strcmp("on", $da_ch)){
      $select_data = $select_data . " and da != '$da'";
      }
   else{
      $select_data = $select_data . " and da='$da'";
      }
   }
if(0 != strlen($proto)){
   if(0 == strcmp("on", $proto_ch)){
      $select_data = $select_data . " and proto != '$proto'";
      }
   else{
      $select_data = $select_data . " and proto = '$proto'";
      }
   }
if(0 != strlen($port)){
   if(0 == strcmp("on", $port_ch)){
      $select_data = $select_data . " and port != '$port'";
      }
   else{
      $select_data = $select_data . " and port = '$port'";
      }
   }
if(0 != strlen($prino)){
   if(0 == strcmp("on", $prino_ch)){
      $select_data = $select_data . " and prino != '$prino'";
      }
   else{
      $select_data = $select_data . " and prino = '$prino'";
      }
   }


echo "<title>zither monitorring save info</title>";
echo "</head>";
echo "<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

echo "<TABLE border=0 bgcolor=FFA500 cellspacing=3 cellpadding=0 width=100%>";
echo "<tr><td align=left><font color=ffffff><b> -> ̥顼</b></font></td></tr>";
echo "</table><br><br>";

print("<font size=1>");
print($version_name);
print("\n");
print(date("Y m d g i s A"));
print("\n");
print($select_data);


$conn = db_connect();
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

echo "<TABLE border=0  WIDTH=50% height=10% BGCOLOR=$my_bocolor>";

echo "<tr bgcolor='#D9DBED'>";
echo "<td>";
print("ȯ(24H)");
echo "</td>";
echo "<td>";
print("");
echo "</td>";
echo "<td>";

echo "</td>";
echo "</tr>";


// ǡ
for($count=0; $count < 24; $count++){

   $select_data_2 = " and ha='$count'";

   $result = db_query($conn, "$select_data$select_data_2");
   if(!$result){
      print("bud query\n");
      exit;
      }
   $num = db_num_rows($result);

   if($maxlen < $num){
      $maxlen = $num;
      }
   $ardata[$count] = $num;

   db_free_result($result);
   $num = 0;
   }


// ǡɽ
for($count=0; $count < 24; $count++){
   echo "<tr bgcolor='#D9DBED'>";

   echo "<td>";
   print($count);
   echo "</td>";

   echo "<td>";
   print($ardata[$count]);
   echo "</td>";

   echo "<td>";

   $width_size = $ardata[$count] / ($maxlen / $by);
   echo "<img src='../img/blue.png' height=10 width=$width_size alt='apoimg'>";
   $width_size = 0;

   echo "</td>";
   echo "</tr>";

   }


echo "</table>";
echo "</font>";

db_Close($conn);

?>
</pre>
<br>
<br>
</body>
</html>
